pyinstapaper package
====================

Submodules
----------

pyinstapaper.instapaper module
------------------------------

.. automodule:: pyinstapaper.instapaper
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyinstapaper
    :members:
    :undoc-members:
    :show-inheritance:
